@@ -425,7 +425,7 @@ def get_markdown_expr(expr: ast.expr, replace: Replace = None) -> str:
         return get_markdown_name(name, replace)
 
     try:
-        return astdoc.ast.unparse(expr, get_link)
+        return astdoc.ast.unparse(expr, get_link, is_type=False)
     except ValueError:
         return ast.unparse(expr)
 
@@ -673,6 +673,7 @@ def _iter_param(param: Parameter) -> Iterator[tuple[ast.expr | str, PartKind]]:
         default = param.default
         if isinstance(default, ast.Constant) and isinstance(default.value, str):
             default = f"{default.value!r}"
+
         yield default, PartKind.DEFAULT
 
 
